% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/filters.R
\name{anova_filter}
\alias{anova_filter}
\title{ANOVA filter}
\usage{
anova_filter(
  y,
  x,
  force_vars = NULL,
  nfilter = NULL,
  p_cutoff = 0.05,
  rsq_cutoff = NULL,
  type = c("index", "names", "full"),
  keep_factors = TRUE,
  ...
)
}
\arguments{
\item{y}{Response vector}

\item{x}{Matrix or dataframe of predictors}

\item{force_vars}{Vector of column names within \code{x} which are always retained
in the model (i.e. not filtered). Default \code{NULL} means all predictors will
be passed to \code{filterFUN}.}

\item{nfilter}{Number of predictors to return. If \code{NULL} all predictors with
p values < \code{p_cutoff} are returned.}

\item{p_cutoff}{p value cut-off}

\item{rsq_cutoff}{r^2 cutoff for removing predictors due to collinearity.
Default \code{NULL} means no collinearity filtering. Predictors are ranked based
on anova test. If 2 or more predictors are collinear, the first ranked
predictor by anova is retained, while the other collinear predictors are
removed. See \code{\link[=collinear]{collinear()}}.}

\item{type}{Type of vector returned. Default "index" returns indices,
"names" returns predictor names, "full" returns a matrix of p values.}

\item{keep_factors}{Logical affecting factors with 3 or more levels.
Dataframes are coerced to a matrix using \link{data.matrix}. Binary
factors are converted to numeric values 0/1 and analysed as such. If
\code{keep_factors} is \code{TRUE} (the default), factors with 3 or more levels are
not filtered and are retained. If \code{keep_factors} is \code{FALSE}, they are
removed.}

\item{...}{optional arguments, e.g. \code{rsq_method}: see \code{\link[=collinear]{collinear()}}.}
}
\value{
Integer vector of indices of filtered parameters (type = "index") or
character vector of names (type = "names") of filtered parameters. If
\code{type} is \code{"full"} full output from \code{\link[matrixTests:oneway]{matrixTests::col_oneway_welch()}} is
returned.
}
\description{
Simple univariate filter using anova (Welch's F-test) using the \code{matrixTests}
package for speed.
}
\examples{
data(iris)
dt <- iris[, 1:4]
y3 <- iris[, 5]
anova_filter(y3, dt)  # returns index of filtered predictors
anova_filter(y3, dt, type = "full")  # shows names of predictors
anova_filter(y3, dt, type = "name")  # full results table

}
